cls
/******************************************************************************/
// MAIN ANALYSIS SCRIPT FOR THE PAPER
// "Ability peer effects in university: Evidence from a randomized experiment"
// by Booij, Leuven & Oosterbeek
/******************************************************************************/


clear all

//goto Ability project folder
//cap cd "x:\Ability"
//cap cd "/Users/hooster1/Dropbox/Ability/"



/******************************************************************************/
// PROGRAMS
/******************************************************************************/

set scheme s1mono
//ssc install estout, replace


// little helper program to spit out nicely formatted estimates
program _se
args b se df
	local p = 2 * ttail(`df', abs(`b' / `se'))
	di as result %8.3f `b' _c
	if (`p' < 0.01)      di "***" _c
	else if (`p' < 0.05) di "** " _c
	else if (`p' < 0.10) di "*  " _c
	else               di "   " _c
	local se = "   (" + trim(string(`se', "%8.3f")) + ")"
	di "`se'" _c
end

// calculate *sample* average tracking effects relative to mixing
// mean,sd specification
program ate 
args tr by
preserve
local cons _cons
local spec : colnames e(b)
local spec : list spec - cons
quietly {
	levelsof `by', local(lvlby)
	
	drop mgpa sdgpa
	bysort g1 : egen mgpa  = peer(gpa)
	bysort g1 : egen sdgpa = peer((gpa - mgpa)^2), f(sqrt)
	foreach l in all `lvlby' {
		matrix accum tmp = `spec' if inlist("`l'", string(`by'), "all"), means(mix_`l')
	}
	drop mgpa sdgpa
	bysort `tr' : egen mgpa  = peer(gpa)
	bysort `tr' : egen sdgpa = peer((gpa - mgpa)^2), f(sqrt)
	foreach l in all `lvlby' {
		matrix accum tmp = `spec' if  inlist("`l'", string(`by'), "all"), means(tr_`l')
		matrix d = tr_`l' - mix_`l'
		matrix e = e(b) * d' , d * e(V) * d'
		noi _se e[1,1] sqrt(e[1,2]) e(N)-e(df_m)
	}
	noi di
}
end


/******************************************************************************/
// DO THE WORK
/******************************************************************************/
use work, clear
egen xcats = group(wisb gpacat_intake cohort)
label var wisb "Adv. Math"
label def wisb 0 "Reg." 1 "Adv."
label val wisb wisb




// FIGURE 1
preserve
	collapse mgpa sdgpa, by(groep)
	set obs 400 //redundant obs for rendering circles
	tempvar x y1 y2 y12 y22 y3
	gen `x'   = .70 * (_n - 1) / (_N - 1)  - .35
	gen `y1'  =  sqrt((1 - (`x' / 0.25)^2)) * 0.18 + 1
	gen `y2'  = -sqrt((1 - (`x' / 0.25)^2)) * 0.18 + 1
	gen `y12' =  sqrt((1 - (`x' / 0.35)^2)) * 0.25 + 1
	gen `y22' = -sqrt((1 - (`x' / 0.35)^2)) * 0.25 + 1
	gen `y3'  = 1
	twoway  ///
	(line `y1' `y2' `y12' `y22' `x', color(gray gray gray gray) lp(solid solid dash dash) ) ///
	(scatter `y3' `x' if `x'==0    , color(gray) msymbol(O) msize(medium) ) ///
	(sc sdgpa mgpa, mc(bmrblue) ms(O) msize(medium)) ///
		, xtitle(mean GPA of peers) ytitle(SD GPA of peers) ///
		xlabel(-1(.5)1.5) ylabel(.4(.2)1.4, angle(0)) scheme(s1mono) ///
		legend(r(1) label(6 "Experimental")  label(1 "Natural 95%") label(3 "Natural 99%") order(6 3 1)) name(scatter)
	//gr export fig/scatter-vargpacircles.pdf, replace
	gr export fig/fig1.eps, replace

restore




// TABLE 1, FIGURE 2, and TABLE A2
// run analysis_priordists to get these


//TEACHERS
preserve
qui {
use data\wteachers, clear
noi mean tchr*


//Teacher char analyses
eststo senpr_r :  reg tchr_prof *gpa*  i.cohort, r
eststo senpr   :  reg tchr_prof *gpa*  i.cohort
eststo senph_r :  reg tchr_ph *gpa*  i.cohort, r
eststo senph   :  reg tchr_ph *gpa*  i.cohort
eststo male_r :  reg tchr_male *gpa* i.cohort, r
eststo male   :  reg tchr_male *gpa* i.cohort



noi di _n _n "Semester 1 courses Micro, Wis, V&M: 3 * (14 + 17 + 17 groups in est sample) = 144 observations"
noi di  "PLUS 17 from MSTRAT(2011) (was OenO in 09 and 10 but those not available, teacher left UvA and lost lists (personal communication))"
noi esttab *_r, keep(*gpa*)  b(%6.2f) se nogaps s(r2 N) obslast staraux star(* 0.10 ** 0.05 *** 0.01)
suest senpr senph male
noi testparm *gpa*
}
restore



// TABLE 2
fvexpand  male age hbo gparaw i.gpacat_intake wisb appordr mgpa sdgpa crd1raw cijfer_av_prop dropout
noi di as text _col(23) 2009 _skip(10) 2010 _skip(10) 2011
qui foreach v in `r(varlist)' {
	// we want means for all factors incl the baseline, so remove b.
	local v = subinstr("`v'", "b.", ".", .)
	noi di as txt "`v'" _col(20) _c
	forv c=2009/2011 {
		qui sum `v' if cohort == `c'
		noi di as res %7.2f r(mean) _c 
		local sd = "(" + trim(strofreal(r(sd), "%6.2f")) + ")"
		if !inlist(`v',0 ,1) noi di %7s "`sd'" _c
		else noi di "       " _c
	}
	noi di
}
qui bys cohort groep (id): gen Ngroups = groep if _n==1
qui gen Nstudents =id
tabstat Ngroups Nstudents, by(cohort) s(count)
drop N*



// TABLE 3
unab   xcontrols : male young old hbo gpa
fvunab rcontrols : ibn.xcats##c.appordr 

local ccredits cluster(groep)
local cavgrade cluster(groep)
local cdropout cluster(groep)

est clear
qui foreach v of var mgpa sdgpa credits avgrade dropout {
	reg `v' `xcontrols' `rcontrols', r `c`v''
	sum `v'
	estadd scalar my  = r(mean)
	estadd scalar sdy = r(sd)
	testparm `xcontrols'
	estadd scalar chi2 = r(df) * r(F)
	estadd scalar pval = r(p)
	est store `v'
}
esttab *, keep(`xcontrols')  obslast sca(my sdy pval r2) b(3) se star(* .1 ** .05 *** .01) nogaps
qui reg mgpa `xcontrols' `rcontrols'
est store mgpa
qui reg sdgpa `xcontrols' `rcontrols'
est store sdgpa
qui suest mgpa sdgpa
testparm `xcontrols'


// TABLE 4
//recenter treatvariables for ease of interpretation
preserve
est clear
sum sdgpa
g mean_sdgpa = r(mean)
replace sdgpa = sdgpa - r(mean)
sum mgpa
g mean_mgpa = r(mean)
replace mgpa = mgpa - r(mean)

local spec0 c.mgpa
local spec1 `spec0'
local spec2 `spec1' c.sdgpa
local spec3 `spec2' c.mgpa#c.sdgpa
local spec4 `spec3' c.gpa#(`spec3')

local x0 `rcontrols'
local x1 `x0' `xcontrols'
local x2 `x1'
local x3 `x1'
local x4 `x1'

local y credits
qui forv s=0/4 {
	reg `y' `spec`s'' `x`s'', cluster(groep)
	testparm `spec`s''
	estadd scalar p = r(p)
	est store s`s'
}
esttab s*, keep(*mgpa* *sdgpa* gpa) order(mgpa sdgpa c.mgpa#c.sdgpa gpa) stats(p) b(3) se star(* .1 ** .05 *** .01) nogaps
noi testparm c.gpa#(`spec3')




// TABLE A3
qui foreach y of var credits avgrade dropout {
	foreach s in 3 4 {
		reg `y' `spec`s'' `x`s'', cluster(groep)
		testparm `spec`s''
		estadd scalar p = r(p)
		capture testparm c.sdgpa c.mgpa#c.sdgpa c.gpa#(`spec3')
		if (_rc!=0)	capture testparm c.sdgpa c.mgpa#c.sdgpa
		capture estadd scalar plin = r(p)
		capture testparm c.gpa#(`spec3')
		capture estadd scalar ph = r(p)
		estadd ysumm
		est store _`y'`s'
	}
}
esttab _*, keep(*mgpa* *sdgpa* gpa) order(mgpa sdgpa c.mgpa#c.sdgpa gpa) sfmt(%6.3f %6.3f %6.0f %6.0f %6.3f %6.3f %6.3f) noobs sca(ymean ysd N N_clust p plin ph) b(3) se star(* .1 ** .05 *** .01) nogaps
restore


// FIGURE 3
//Effect mGPA by sdGPA
qui {
qui eststo main: reg credits (c.sdgpa c.mgpa c.sdgpa#c.mgpa)##c.gpa  i.xcat##c.appordr male old young hbo , cluster(groep)
qui margins, dydx(mgpa) at(sdgpa=(0.3(0.1)1.5)) level(90)
marginsplot,  ///
	yline(0)  ///
	plotopt(ms(O) lp(dash) mc(black) ) ///
	recastci(rarea) ciopt(fcolor(bluishgray) lcolor(bluishgray)) ///
	ytitle(Marginal effect mean GPA of peers) ///
	xtitle(SD GPA of peers) ///
	name(mgpa2x, replace) title("") ///
	addplot((function y=0, ra(0.29 1.51) ylabel(-1(0.5)1, angle(0)) xlabel(0.3 0.4 0.5 "{bf:0.5}" 0.6(.1)1 1.1 "{bf:1.1}" 1.2(.1)1.5) lc(black)  sort yline(0, lc(black)))) legend(off)
//gr export fig/dydx_mgpa_x_sdgpa.pdf, replace
gr export fig/fig3a.eps, replace

//Effect sdGPA by mGPA
qui margins, dydx(sdgpa) at(mgpa=(-1(0.2)1.6)) level(90) vsquish
marginsplot,  ///
	yline(0)  ///
	plotopt(ms(O)  lp(dash) mc(black) ) ///
	recastci(rarea) ciopt(fcolor(bluishgray) lcolor(bluishgray)) ///
	ytitle(Marginal effect SD GPA of peers) ///
	xtitle(Mean GPA of peers) ///
	name(sdgpa2x, replace) title("") ///
	addplot((function y=0, ra(-1.01 1.61) ylabel(-1(0.5)1, angle(0)) xlabel(-1 -.8 -.6 "{bf:-.6}" -.4(.2).4 .6 "{bf:.6}" .8(.2)1.6) lc(black)  sort yline(0, lc(black)))) legend(off)
//gr export fig/dydx_sdgpa_x_mgpa.pdf, replace
gr export fig/fig3b.eps, replace

//Effect mGPA by myGPA over homo vs hetero groups
est restore main
margins, dydx(mgpa) at(gpa=(-1.5(0.5)1.5) sdgpa=(0.50 1.14)) level(90)
margins, dydx(mgpa) at(gpa=(-2(0.5)2) sdgpa=(0.50 1.14)) level(90)
mat res = r(table)
mat at = r(at)
mat at = at[.,"sdgpa"], at[.,"gpa"], res[1 ,1...]', res[5..6, 1...]'
cap drop at*
svmat at
preserve
keep at*
egen x = group(at1)
drop if x==.
drop at1
reshape wide at3 at4 at5, i(at2) j(x)
se2plot at31 at41 at51 at32 at42 at52 at2, ///
	copt(lpat(dash ..) ms(O Oh) mc(black ..)) ///
	xtitle(Own GPA) ylabel(, angle(0)) ytitle(Marginal effect mean GPA of peers) ///
	xlabel(-2(0.5)2) legend(order(1 "Homogeneous groups" 3 "Heterogeneous groups")) ///
	legend(region(lcolor(white))) ylabel(-1(0.5)1) name(m1, replace)
restore
//gr export fig/dydx_mgpa_x_gpa.pdf, replace
gr export fig/fig3c.eps, replace

//Effect sdGPA by myGPA over Low v.s. High ability groups
est restore main
margins, dydx(sdgpa) at(gpa=(-1.5(0.5)1.5) mgpa=(-0.60 0.65)) level(90)
margins, dydx(sdgpa) at(gpa=(-2(0.5)2) mgpa=(-0.60 0.65)) level(90)
mat res = r(table)
mat at = r(at)
mat at = at[.,"mgpa"], at[.,"gpa"], res[1 ,1...]', res[5..6, 1...]'
cap drop at*
svmat at
preserve
keep at*
egen x = group(at1)
drop if x==.
drop at1
reshape wide at3 at4 at5, i(at2) j(x)
se2plot at31 at41 at51 at32 at42 at52 at2, ///
	copt(lpat(dash ..) ms(O Oh) mc(black ..)) ///
	xtitle(Own GPA) ylabel(, angle(0)) ytitle(Marginal effect SD GPA of peers) ///
	xlabel(-2(0.5)2) legend(order(1 "Low ability groups" 3 "High ability groups")) ///
	legend(region(lcolor(white))) ylabel(-1(0.5)1) name(sd1, replace)
restore
//gr export fig/dydx_sdgpa_x_gpa.pdf, replace
gr export fig/fig3d.eps, replace

}



// TABLE 5 & 6
//use if treat==1 using work, clear
//egen xcats = group(wisb gpacat_intake cohort)
gen g1  = 1                                      // mix
set seed 11032016
g rx = runiform()
sort gpa rx
foreach c in 2 3 {
	gen g`c'a = floor(`c'*(_n-1)/_N) + 1
}
recode g3a (1 3 = 1)       , gen(g3m)            // bifurcate
recode g3a (1 2 = 1) (3=2) , gen(g3h)            // mix two bottom groups
recode g3a (2 3 = 2)       , gen(g3l)            // mix two top groups

program track_effects
	di as txt "2-way tracking" _col(15) _c
	ate g2 g2
	di as txt "3-way tracking" _col(15) _c
	ate g3a g3a
	di as txt "track low"      _col(15) _c
	ate g3l g3a
	di as txt "track middle"   _col(15) _c
	ate g3m g3a
	di as txt "track high"     _col(15) _c
	ate g3h g3a
end


foreach y of var credits avgrade dropout {
	qui reg `y' c.gpa##(c.mgpa c.sdgpa c.mgpa#c.sdgpa) ibn.xcats##c.appordr male young old hbo gpa, cluster(groep)
	di as inp "`y'"
	track_effects
	tabstat `y', by(g3a) s(mean sd) f(%6.3f)
}




// FIGURE 4
preserve
collapse mgpa ngrrel*, by(groep) //collapse to group level
sort mgpa
gen mg3 =(_n/_N>1/3) + (_n/_N>2/3)     //split sample in lowest 16, mid 16, and lowest 16 mgpa
reshape long ngrrel, i(groep) j(month) //put months of the year in longform for pic
bys month: egen mngrrel = mean(ngrrel)
bys mg3 month:  egen mg3ngrrel = mean(ngrrel)
forv i = 0 / 2 {
	gen mg3_`i' =  mg3ngrrel if   mg3==`i'
}
twoway (line mg3_0 mngrrel  mg3_2   month, sort lp(solid dash solid) lc(bmrblue black dkred)  ///
	text( 0.73 9 "Average")  text( 0.87 9 "High GPA group")  text( 0.54 9 "Low GPA group")  ytitle("Groupsize as fraction of initial") ///
	ylabel(0(0.2)1,  angle(h)) xlabel(1(1)10) xtitle("Month"))  , name(ngr, replace) legend(off)
//graph export fig/ngr_by_mgpa.pdf, replace
graph export fig/fig4.eps, replace
restore


// TABLE 7
local controls ibn.xcats##c.appordr male young old hbo gpa
local peervars c.mgpa c.sdgpa c.mgpa#c.sdgpa c.gpa#(c.mgpa c.sdgpa c.mgpa#c.sdgpa)
local peeriv   c.amgpa c.asdgpa c.amgpa#c.asdgpa c.gpa#(c.amgpa c.asdgpa c.amgpa#c.asdgpa)
local y credits

program pvals
	testparm c.mgpa c.sdgpa c.mgpa#c.sdgpa c.gpa#(c.mgpa c.sdgpa c.mgpa#c.sdgpa)
	estadd scalar p = r(p)
	testparm c.gpa#(c.mgpa c.sdgpa c.mgpa#c.sdgpa)
	estadd scalar ph = r(p)
end


// calculate track effects before recentering sdgpa (we set sdgpa=1 in mixing)
qui reg `y' `peervars' `controls', cluster(groep)
track_effects
qui ivregress 2sls `y' (gsize = noshow) `peervars' `controls', cluster(groep)
track_effects
qui ivregress 2sls `y' (`peervars' gsize = noshow `peeriv') `controls', cluster(groep)
track_effects

preserve
//recenter treatvariables for ease of interpretation
sum sdgpa
local mean_sdgpa = r(mean)
replace sdgpa = sdgpa - r(mean)
sum mgpa
local mean_mgpa = r(mean)
replace mgpa = mgpa - r(mean)
noi di "No show stats"
bys groep: gen grid = _n
noi sum noshow if grid==1


est clear
qui eststo ols: qui reg `y' `peervars' `controls', cluster(groep)
qui pvals
qui reg ngrav noshow `peervars' `controls', cluster(groep)
noi lincom noshow
qui eststo iv1: ivregress 2sls `y' (ngrav = noshow) `peervars' `controls', cluster(groep) first
qui pvals
qui estat firststage, all
qui mat m= r(singleresults)
qui estadd mat fsF=m[1,4]
mat list e(fsF), f(%6.3f)
qui eststo iv2: ivregress 2sls `y' (`peervars' ngrav = noshow `peeriv') `controls', cluster(groep)
qui pvals
qui estat firststage, all
qui mat m= r(singleresults)
qui estadd mat fsF=m[1..7,4]
mat list e(fsF), f(%6.3f)
esttab *, keep(*gpa* ngrav) order(mgpa sdgpa c.mgpa#c.sdgpa gpa) b(3) se star(* .1 ** .05 *** .01) sca(p ph) noobs sfmt(%6.3f) nogaps



// TABLE A4
est clear
foreach y of var sur wc2fast wc2slow    wcstim peercond peerinter peerinv {
	eststo `y': qui reg `y' `peervars' `controls', cluster(groep)
	qui pvals
	qui estadd ysumm
}
esttab *, keep(*gpa*) order(mgpa sdgpa c.mgpa#c.sdgpa gpa) b(3) se star(* .1 ** .05 *** .01) sca(ymean ysd N_clust N p ph) noobs sfmt(%6.3f %6.3f %6.0f %6.0f %6.3f %6.3f ) nogaps
restore

// TABLE 8
foreach y of var wc2fast wc2slow  wcstim peercond peerinter peerinv {
	di as inp "`y'"
	qui reg `y' `peervars' `controls', cluster(groep)
	track_effects
}




// APPENDIX B: FRACTIONS
// calculate *sample* average tracking effects relative to mixing
// fraction specification
capture program drop ate
program ate
args tr by
preserve
local cons _cons
local spec : colnames e(b)
local spec : list spec - cons
quietly {
	levelsof `by', local(lvlby)
	drop ftgpa fbgpa
	bysort g1 : egen ftgpa = peer(g3a==3)
	bysort g1 : egen fbgpa = peer(g3a==1)
	foreach l in all `lvlby' {
		matrix accum tmp = `spec' if inlist("`l'", string(`by'), "all"), means(mix_`l')
	}
	drop ftgpa fbgpa
	bysort `tr' : egen ftgpa = peer(g3a==3)
	bysort `tr' : egen fbgpa = peer(g3a==1)
	foreach l in all `lvlby' {
		matrix accum tmp = `spec' if inlist("`l'", string(`by'), "all"), means(tr_`l')
		matrix d = tr_`l' - mix_`l'
		matrix e = e(b) * d' , d * e(V) * d'
		noi _se e[1,1] sqrt(e[1,2]) e(N)-e(df_m)
	}
	noi di
}
end

// TABLE B2
local y credits
unab   xcontrols : male young old hbo gpa
fvunab rcontrols : ibn.xcats##c.appordr 
local specadd0 c.fbgpa c.ftgpa
local specadd1 c.fbgpa#c.fbgpa c.ftgpa#c.ftgpa
local specadd2 c.fbgpa#c.fbgpa#c.fbgpa c.ftgpa#c.ftgpa#c.ftgpa
local specadd3 c.fbgpa#c.fbgpa#c.fbgpa#c.fbgpa c.ftgpa#c.ftgpa#c.ftgpa#c.ftgpa
local spec0 `specadd0'
local spec1 `spec0' `specadd1'
local spec2 `spec1' `specadd2'
local specadd4 c.gpa#(`spec2')
local spec3 `spec2' `specadd3'
local spec4 `spec2' `specadd4'


forv s=4/4 { //start at 1 to see estimated tracking effects for all specs 
	di as inp "`y', spec`s'"
	qui reg `y' `spec`s'' `rcontrols' `xcontrols', cluster(groep)
	track_effects
}

// TABLE B1
//recenter treatvariables for ease of interpretation
sum ftgpa
replace ftgpa = ftgpa - r(mean)
sum fbgpa
replace fbgpa = fbgpa - r(mean)

est clear
local y credits
qui forv s=0/4 {
	reg `y' `spec`s'' `rcontrols' `xcontrols', cluster(groep)
	testparm `spec`s''
	estadd scalar p = r(p)
	testparm `specadd`s''
	estadd scalar padd = r(p)
	est store s`s'
}
esttab *, keep(*gpa*) stats(p padd) b(3) se star(* .1 ** .05 *** .01) nogaps



// TABLE B3
//recenter treatvariables for ease of interpretation
sum sdgpa
local mean_sdgpa = r(mean)
replace sdgpa = sdgpa - r(mean)
sum mgpa
local mean_mgpa = r(mean)
replace mgpa = mgpa - r(mean)
est clear
local controls ibn.xcats##c.appordr male young old hbo gpa
fvunab peervars: c.mgpa c.sdgpa c.mgpa#c.sdgpa c.gpa#(c.mgpa c.sdgpa c.mgpa#c.sdgpa)
local y credits
local i 1
qui eststo noc1: reg `y' `peervars' `controls'
foreach mpeer in "" "mmale" "mage" "mappordr" "mmale mage mappordr" {
	
	qui eststo b`i': reg `y' `peervars' `controls' `mpeer'
	qui if (`i'>1) {
		suest noc1 b`i', cluster(groep)
		test [noc1_mean== b`i'_mean]: `peervars'
		local p=r(p)
		}
	qui eststo b`i': reg `y' `peervars' `controls' `mpeer', cluster(groep)
	qui if (`i'>1) estadd sca peq = `p'
	local ++i
}
esttab b*, keep(*gpa*) stats(peq) b(3) se star(* .1 ** .05 *** .01) nogaps



// TABLE B4
//recenter treatvariables for ease of interpretation
est clear
local i 1
qui eststo noc1: reg `y' `peervars' `controls'
foreach if in "" "& cohort!=2009" "& cohort!=2010" "& cohort!=2011" {
	noi qui eststo b`i': reg `y' `peervars' `controls' if 1 `if'
	qui if (`i'>1) {
		suest noc1 b`i', cluster(groep)
		test [noc1_mean== b`i'_mean]: `peervars'
		local p=r(p)
		}
	qui eststo b`i': reg `y' `peervars' `controls' if 1 `if', cluster(groep)
	qui if (`i'>1) estadd sca peq = `p'
	local ++i
}
esttab b*, keep(*gpa*) stats(peq) b(3) se star(* .1 ** .05 *** .01) nogaps


//STRATIFICATION variables by MGPA, HOMO/HETERO, own GPA
bys groep (id): gen t=_n
// stratified by mgpa
egen m=mean(gpa), by(groep)
_pctile m if t==1, p(50)
local p50 = r(r1)
g mgpa_above = (m > `p50') //eerst werdt 1109 erbij gerekent, maar dat hoort niet

// stratified by sdgpa
egen s=sd(gpa), by(groep)
_pctile s if t==1, p(50)
local p50 = r(r1)
g sd_above = (s > `p50')

// TABLE B5
est clear
qui eststo b1:reg `y' c.mgpa#sd_above  sd_above `controls' , cluster(groep)
qui testparm c.mgpa#sd_above, eq
qui estadd sca peq=r(p)
qui eststo b2:reg `y' c.sdgpa#mgpa_above  mgpa_above `controls' , cluster(groep)
qui testparm c.sdgpa#mgpa_above, eq
qui estadd sca peq=r(p)
esttab b*, keep(*gpa* *_ab*) drop(gpa) stats(peq) b(3) se star(* .1 ** .05 *** .01) nogaps noomit var(30)

// TABLE B6
est clear
gen gpa_above = (g2a==2)
qui eststo b1:reg `y' gpa_above#(c.mgpa c.sdgpa c.mgpa#c.sdgpa) gpa_above `controls' , cluster(groep)
test (0b.gpa_above#c.mgpa=1.gpa_above#c.mgpa) (0b.gpa_above#c.sdgpa =1.gpa_above#c.sdgpa) (0b.gpa_above#c.mgpa#c.sdgpa =1.gpa_above#c.mgpa#c.sdgpa)
qui estadd sca peq=r(p)
esttab b*, keep(*gpa* *_ab*) drop(gpa) stats(peq) b(3) se star(* .1 ** .05 *** .01) nogaps noomit var(30)




//TABLE C1
sum surv*raw , format


