cls
/******************************************************************************/
// ANALYSIS SCRIPT FOR THE ASSIGNMENT DISTRIBUTIONS FOR THE PAPER
// "Ability peer effects in university: Evidence from a randomized experiment"
// by Booij, Leuven & Oosterbeek
/******************************************************************************/
qui {
clear all

//goto Ability project folder
//cap cd "X:\Ability"
//cap cd "/Users/hessel/Dropbox/Ability/"



// IMPORT ASSIGNMENT MATRICES
// these come from the excel file that was used to administer student Intake

tempfile temp
foreach c in 2009 2010 2011 {
	insheet using data/pgr`c'/assignment/2.assignprobmatrix.csv, clear
	gen cohort = `c'
	cap append using `temp'
	save `temp', replace
}
drop if fisc==1 | f0==.
sort cohort pgr
g group = _n



//FIGURE 2
preserve
// average
sum f1
local f1 = r(mean)
local my = `f1' * sqrt(3) / 2
sum f2 
local mx = r(mean) + `f1'/2

// points
bys f0 f1 f2: g n = _N
bys f0 f1 f2: keep if _n==1

g x = f2 + f1/2
g y = f1 * sqrt(3) / 2

// add average
set obs `=_N + 1'
replace x = `mx' if _n==_N
g my = `my' if _n==_N

// triangle
local N = _N
set obs `=_N + 3'

replace x = 0 in `= `N' + 1' 
replace x = 0.5 in `= `N' + 2' 
replace x = 1 in `= `N' + 3' 

g y1 = 0 in `= `N' + 1' 
replace y1 = sqrt(3) / 2 in `= `N' + 2'
replace y1 = 0 in `= `N' + 3' 

g y2 = 0 in `= `N' + 1' 
replace y2 = 0 in `= `N' + 2'
replace y2 = 0 in `= `N' + 3' 

// plot
local ar = sqrt(3) / 2
local xsize = 6
local ysize = `xsize'*`ar'

twoway ///
	(sc my x, ms(X) mc(black) msize(huge) text(`my' `=`mx'+.1' "Average")) ///
	(sc y x [fw=n], ms(Oh) mc("00 96 186") xaxis(1) xtitle("", axis(1)) xscale(noline) xlabel(0 "GPAcat0" 1 "GPAcat2", axis(1))) ///
	(line y1 y2 x, lcol(black ..) lpat(shortdash ..) xaxis(2) xtitle("", axis(2)) xscale(noline  axis(2)) xlabel(0.5 "GPAcat1", axis(2))) ///
	, scheme(s1mono) name(triangle) ///
	yscale(off) plotregion(lcolor(none)) legend(off) ///
	aspectratio(`ar') xsize(`xsize') ysize(`ysize') ///
	
//gr export fig/assignment_triangle_prior.pdf,replace
gr export fig/fig2.eps,replace
restore





//TABLE 1	
forv c = 0 / 2 {
	bys cohort catb (pgr): egen t = total(f`c')
	gen prob`c' = f`c' / t
	drop t
}
bys cohort (pgr): gen groupyr = _n
keep groupyr group cohort catb prob*

noi di _n _n in white "Table 1: Marginal prob on which assignment was based (reversed calculated)"
bys cohort catb: gen fraqgr = 1 / _N
reg fraqgr cohort#catb#c.prob?, nocons
mat b = e(b)
mat table = (b[1,1..6] \ b[1,7..12] \ b[1,13..18])
mat rown table = cat0 cat1 cat2
noi mat list table, format(%6.2f)






//TABLE A2
drop fraqgr
reshape wide group  prob* catb , i(groupyr) j(cohort)
format %4.0f catb* group*  
format %4.2f prob*
noi di _n _n in white  "Table A2: assignment probs"
noi tabstat group2009 - prob22009 catb2009 group2010 - prob22010 catb2010 group2011 - prob22011 catb2011, by(groupyr) format nototal



}

