cls
/******************************************************************************/
// CREATE DATA WORK FILE WITH SELECTED SAMPLE AND CONSTRUCTED VARIABLES FOR
// "Ability peer effects in university: Evidence from a randomized experiment"
// by Booij, Leuven & Oosterbeek
/******************************************************************************/
qui {
clear all


//goto Ability project folder
//cap cd "x:\Ability"
//cap cd "/Users/hooster1/Dropbox/Ability/"


//open raw merged (groups and registry outcomes) datafile 
use "data\wmerged", clear



//GENVARS
//AGE CLASSES
bys cohort (age id):     gen age3cat = (_n/_N>1/3) + (_n/_N>2/3)
gen young = (age3cat==0)
gen old   = (age3cat==2)


//STANDARDIZE GPA and OUCTOMES PER COHORT
ren gpa gparaw
ren crd1 crd1raw
bys cohort: egen gpa = stdof(gparaw)
bys cohort: egen credits = stdof(crd1raw)		 
bys cohort: egen avgrade = stdof(cijfer_av_prop)
label var gpa "standardized high school GPA"
label var credits "standardized FY credits"
label var avgrade "standardized FY average grade"


// Mean peer characteristics
foreach v of varlist gpa male age appordr {
	bys groep : egen s`v' = sum(`v')
	bys groep : gen  m`v' = (s`v' - `v' ) / (_N - 1)
	local vcap=upper("`v'")
	label var m`v' "Average `vcap' of peers"
}

//SDGPA
bys groep : egen sgpasq  = sum((gpa - mgpa)^2)
bys groep : gen  sdgpa  = sqrt((sgpasq - (gpa - mgpa)^2) / (_N - 1))
label var sdgpa "S.D. GPA of peers"
bys groep : egen mgpaall  = mean(gpa)
bys groep : egen sdgpaall = sd(gpa)
label var mgpaall "Average GPA of group"
label var sdgpaall "S.D. GPA of group"
bys groep : egen mappordrall  = mean(appordr)
label var mappordrall "Average appordr of group"


// gen group fractions GPA Low, Mid, High
gsort cohort gpa - id 
by cohort: gen gpa3cat =(_n/_N>1/3) + (_n/_N>2/3)
gen gpab = (gpa3cat==0)
gen gpam = (gpa3cat==1)
gen gpat = (gpa3cat==2)
label var gpab "gpa in bottum 3rd"
label var gpam "gpa in middle 3rd"
label var gpat "gpa in top 3rd"
label var gpa3cat "equal 1/3 fraq cat from register"
foreach v in  b m t {  										
	bysort groep: egen f`v'gpaall = mean(gpa`v')
	bysort groep: gen f`v'gpa = (_N*f`v'gpaall - gpa`v')/(_N-1)
	label var f`v'gpaall "fraq. gpa `v'"
	label var f`v'gpa "fraq. gpa `v' peers"
}
bys groep : g gsize = _N





//STD SURVEY variables; set missing to 0
tempvar t
foreach v of varlist surv* {
	clonevar `v'raw = `v'
	reg `v' i.cohort##surweb
	predict `t' 
	replace `v' = `t' if `v'==. & sur==1        	//recode missings to average of cohort if filled survey
	drop `t'
	egen `t' = stdof(`v') if sur==1, by(cohort)     //standardize
	replace  `v' = `t'
	replace  `v' = 0 if sur==1 & `v'==.             //set to 0 item missing but did fill survey (i.e. cohort 2009 did not include some Q) 
	drop `t'
}

// ****************************





// *************************************************
// Sumstats per group
noi di _n _n "Show characteristics per group"
noi tabstat wisb gpa gpab gpam gpat male age appordr fisc hbo, by(groep) format(%6.2f)




// *************************************************
// GEN DYNAMIC GROUPSIZE
qui forv i = 1 / 10 {
	cap bys groep: egen ngr`i' = total(lmprop>=`i')
	bys groep: gen  ngrrel`i' = ngr`i'/ngr1
}
by groep: egen ngrrelav = mean((lmprop/10))
gen ngravall = ngr1 * ngrrelav
gen ngrav = ngravall - (lmprop/10) //take out person i to get only groupsize of other students




// *************************************************
// GET original assignment on intake list that includes no-shows
merge 1:1 id cohort using "data\wgr_pstats_prior"
ren n0 ngr0
//In 2009 there was re-asignment after 1 week to fill the no-show spots. Two groups were spread over the remaining, trying to stay close to the prior assignment. 
//The prior assignment is an instrument for the observed assignment in terms of peer-chars, but there were no-shows at this stage (i.e. within this week),
//so no instrument for group size. Hence the group size at 0 (intake) is equal to 1 (first month).
replace ngr0 = ngr1 if cohort==2009 
gen noshow = ngr0-ngr1
drop if _merge==2
drop _merge





// *******************************
//SAMPLE SELECTION
//Select estimation sample; Remove non-random groups with late arrivals
gen pgrlate = inlist(groep, 904, 916)    //Remove two groups with late arrivals that were not randomly assigned
gen pgrfisc = inlist(groep, 1016, 1112)  //Remove two groups of fiscal economics students that were not randomly assigned
noi di _n _n "Drop late (2009) and fisc (2010/2011) non-random groups, and excess fisc students that were placed in other groups"
noi tab groep pgrfisc if pgrlate | pgrfisc
drop if pgrlate | pgrfisc

noi di _n _n "Drop 10 fisc students that appeared in non fisc (experimental) group. These are not part of the analysis but do constitute the peer group."
noi drop if fisc==1









// *******************************
//RENORMALIZATION for Exposition
//renormalize outcomes and gpa; correct for dropped non-random groups
tempvar c a g
ren credits `c'
bys cohort: egen credits = stdof(`c'), m(0.00000001) std(1.000533785) //standardized by cohort, inflated slightly such that sample SD is exactly 1
ren avgrade `a'
bys cohort: egen avgrade = stdof(`a'), m(0.00000001) std(1.000571226)
ren gpa `g'
bys cohort: egen gpa = stdof(`g'), m(0.00000001) std(1.000533785)



// ************************************
// Mechanism vars
egen wc2slow=stdof(surv15+surv16+surv22), m(0.00000001)
egen wc2fast=stdof(surv14+surv17+surv20), m(0.00000001)
egen wcstim=stdof(surv10+surv11+surv18), m(0.00000001)
egen peerconducive=stdof(surv1+surv2+surv6), m(0.00000001)
egen peerinter=stdof(surv3+surv4+surv5), m(0.00000001)
egen peerobstruct=stdof(-surv12-surv13+surv8+surv9+surv19+surv21), m(0.00000001)
gen  peerinvolve = -peerobstruct 



drop _*
compress
saveold work, replace









}

