!* version 1.0 6jan2012 Edwin Leuven (e.leuven@gmail.com)
version 12
program se2plot
syntax varlist [if], [Colors(string asis) Alpha(real 0.5) COPTions(string asis)] *

marksample touse, novar

local n : word count `varlist'
tokenize `varlist'
if (`n'==5) {
	local y0  `1'
	local se0 `2'
	local y1  `3'
	local se1 `4'
	local x   `5'
	tempvar d0 d1 w0 w1
	qui g `d0' = `y0' - 1.96 * `se0'
	qui g `d1' = `y0' + 1.96 * `se0'
	qui g `w0' = `y1' - 1.96 * `se1'
	qui g `w1' = `y1' + 1.96 * `se1'
} 
else if (`n'==7) {
	local y0 `1'
	local d0 `2'
	local d1 `3'
	local y1 `4'
	local w0 `5'
	local w1 `6'
	local x  `7'
} 
else {
	di as err "Wrong nr. of variables check help {help se2plot}"
}

// get colors and blend
if (`"`colors'"'=="") local colors bluishgray sienna*.5

gr_setscheme , passthru refscheme // handle scheme

tokenize `"`colors'"'
color_load `1'
local col1 "`s(rgb)'"
color_load `2'
local col2 "`s(rgb)'"

forv i = 1/3 {
	local c1 : word `i' of `col1'
	local c2 : word `i' of `col2'
	local c3 = int((1 - `alpha') * `c1' + `alpha' * `c2')
	local col3 `col3' `c3' 
}

quietly {
	preserve

	keep if `touse'
	bys `x' : keep if _n==1

	// expand grid if necessary (when areas cross)
	forv i = 0/1 {
		forv j = 0/1 {
			tempvar e dx expand dddx dwdx
			g `e'  = _n < _N & sign(`w`i'' - `d`j'') != sign(`w`i''[_n + 1] - `d`j''[_n + 1])
			g double `dwdx' = (`w`i''[_n + 1] - `w`i'') / (`x'[_n + 1] - `x') if `e'
			g double `dddx' = (`d`j''[_n + 1] - `d`j'') / (`x'[_n + 1] - `x') if `e'
			g double `dx' = (`w`i'' - `d`j'') / (`dddx' - `dwdx') if `e'
			expand 1 + `e', gen(`expand')
			sort `x' `expand'
			forv k = 0/1 {
				replace `d`k'' = `d`k'' + `dx' * (`d`k''[_n + 1] - `d`k'') / (`x'[_n + 1] - `x') if `expand' > 0
				replace `w`k'' = `w`k'' + `dx' * (`w`k''[_n + 1] - `w`k'') / (`x'[_n + 1] - `x') if `expand' > 0
				replace `y`k'' = . if `expand' > 0
			}
			replace `x' = `x' + `dx' if `expand' > 0
		}
	}

	// construct overlapping and nonoverlapping areas
	tempvar d11 d10 d00 d01 

	g `d11' = `d1'
	g `d10' = max(`d0', `w1')
	replace `d11' = . if `d10' > `d11'

	g `d01' = min(`d1', `w0')
	g `d00' = `d0'
	replace `d01' = . if `d00' > `d01'

	tempvar w11 w10 w00 w01 

	g `w11' = `w1'
	g `w10' = max(`w0', `d1')
	replace `w11' = . if `w10' > `w11'

	g `w01' = min(`w1', `d0')
	g `w00' = `w0'
	replace `w01' = . if `w00' > `w01'

	tempvar o11 o10 o00 o01 

	g `o11' = min(`w1', `d1')
	g `o10' = max(`w0', `d0')
	replace `o11' = . if `o11' < `o10' | missing(`d1',`d0',`w1',`w0')
	tempvar zero
	g `zero'= 0
}

twoway ///
	(rarea `d11' `d10' `x', col("`col1'") cmissing(n) sort) ///
	(rarea `d01' `d00' `x', col("`col1'") cmissing(n) sort) ///
	(rarea `w11' `w10' `x', col("`col2'") cmissing(n) sort) ///
	(rarea `w01' `w00' `x', col("`col2'") cmissing(n) sort) ///
	(rarea `o11' `o10' `x', col("`col3'") cmissing(n) sort) ///
	(conne `y0' `y1' `x', ms(Oh O) sort `coptions') ///
	(line `zero' `x', ms(i i ) lc(black) lw(thin) sort yline(0)) ///
	, legend(order(6 7)) `options'

end


program color_load , sclass
	tempname mycolor
	.`mycolor' = .color.new , style(`0')
	sret local rgb "`.`mycolor'.setting'"
	sret local color `""`0'""'
end
